@@ -5,6 +5,11 @@ use std::{
     os::raw::{c_char, c_int, c_void},
     ptr,
 };
+#[cfg(feature = "deps")]
+pub mod deps {
+    pub use nstd_collections;
+}
+
 #[allow(non_camel_case_types)]
 type byte = u8;
 
@@ -97,7 +102,7 @@ pub unsafe extern "C" fn nstd_std_env_free_args(args: &mut NSTDVec) -> c_int {
     for i in 0..args.size {
         let cstrptr = nstd_std_collections_vec_get(args, i) as *const *mut c_char;
         if !cstrptr.is_null() {
-            CString::from_raw(*cstrptr);
+            drop(CString::from_raw(*cstrptr));
         }
     }
     nstd_std_collections_vec_free(args)
